#
# spec file for package djvulibre-djview4
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           djvulibre-djview4
Version:        4.12
Release:        2.7
Summary:        Portable DjVu Qt4 Based Viewer and Browser Plugin
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://djvu.sourceforge.net/djview4.html
Source:         https://downloads.sourceforge.net/djvu/djview-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libqt5-linguist
# Upstream does not supply a configure script; libtool needed to generated one (v 4.12)
BuildRequires:  libtool
BuildRequires:  pkg-config
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(ddjvuapi)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)
Requires:       djvulibre >= 3.5.18
%if 0%{?suse_version} < 1550
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
%endif
Conflicts:      djvulibre-djview3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
DjView4 is a viewer and browser plugin for DjVu documents,based on the
DjVuLibre-3.5 library and the Qt4 toolkit.

%prep
%setup -q -n djview4-%{version}
sed -i 's|PLUGINSDIR|%{_libdir}/browser-plugins|g' nsdejavu/nsdejavu.1.in 

%build
export QMAKE=/usr/bin/qmake-qt5
NOCONFIGURE=1 ./autogen.sh
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} pluginsdir=%{_libdir}/browser-plugins install %{?_smp_mflags}
ln -s %{_bindir}/djview %{buildroot}%{_bindir}/djview4
%suse_update_desktop_file -i djvulibre-djview4 Qt Graphics Viewer

%if 0%{?suse_version} < 1550
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%license COPYING COPYRIGHT
%doc NEWS README README_translations
%doc %{_mandir}/man1/*
%{_bindir}/djview4
%{_bindir}/djview
%{_libdir}/browser-plugins
%{_datadir}/djvu/djview4/
%{_datadir}/applications/djvulibre-djview4.desktop
%{_datadir}/icons/hicolor
%dir %{_datadir}/djvu/

%changelog
* Wed May  4 2022 Marcus Meissner <meissner@suse.com>
- update source url to https
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.12:
  * Fixes for recent compilers.
  * Fixes for Qt-5.15.
  * Fixes in tiff2pdf.c.
  * Updated documentation (most browsers no longer support
    plugins).
  * Updated translations.
- Run autogen.sh to generate configure script as source tarball
  no longer has one; BuildRequires: libtool.
- Only run post(un) scriptlets for openSUSE < 1550; they are void
  for newer openSUSE and directly handled by file triggers.
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Thu Apr 19 2018 schwab@suse.de
- npsdk-aarch64-support.patch: remove obsolete patch
* Tue Nov 22 2016 pgajdos@suse.com
- updated to 4.10.6
  - Support for pinch gestures
  - New shortcuts on mac
  - Support for high dpi displays
  - Spanish translations
  - Bug fixes
  - Workaround for qt5.5 embed bug
* Thu Mar 19 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Build qt5 version
- Remove no longer needed patches
  * djview4-nsplugin_manpage.patch
  * djview4-nsplugin_dir.patch
- Update to 4.10
  * Bug fixes: layout, usability, preferences, locale selection
  * Works with both Qt4 and Qt5
  * Build uses automake/qmake hybrid (instead of autoconf/qmake).
  * Layout annotations are honored in multipage mode
  * Experimental OpenGL rendering
  * Slideshow mode
* Wed Sep 11 2013 schwab@suse.de
- npsdk-aarch64-support.patch: Add support for AArch64 in npsdk
* Wed Mar 27 2013 pgajdos@suse.com
- updated to 4.9:
  * Added language selection in preference.
  * Added option to override printing and saving restrictions.
  * Automatic reloading of djvu documents when the file is changed.
  * New chinese translations.
  * Improved network code (needs Qt>=4.4.)
  * Remember the last visited position for the last 50 documents.
- dropped qt-4.8.patch, upstream is using qSwap()
* Mon Dec 19 2011 pgajdos@suse.com
- build with qt 4.8
  * added qt-4.8.patch
* Mon Oct 31 2011 pgajdos@suse.com
- updated to version 4.8:
  * Added option to invert luminance.
  * Added shortcut ctrl+g to go to the page combo.
  * Fixed export issues under win32.
  * Mouse wheel can be configured to control the zoom.
  * Animated page movements.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue May 24 2011 pgajdos@novell.com
- updated to version 4.7:
  * Fix for crash on quick PgUp PgDn sequences.
  * Fix scrollbars in continuous mode.
  * Fix plugin for some webkit based browsers.
* Tue Nov 16 2010 pgajdos@suse.cz
- updated to version 4.6:
  * Show total page number in page combo and page info box.
  * Decode percent encoding in annotation and outline hyperlinks.
  * Properly handle non-ascii filenames in export and save dialogs.
  * Subtle changes to PgUp/PgDn/Home/End/Space/Backspace view changes.
  * Fixed suffix management in export/save/print dialogs.
* Wed Aug  5 2009 mseben@suse.cz
- update to version 4.5
  * Fixed priority of annotation options.
  * Fixed plugin for recent versions of gcc.
  * Added showposition in advanced option copyUrl.
  * New advanced mode to display hidden text.
  * Lens display annotations and hidden text.
  * Nsdejavu can use the XEmbed protocol when available.
  * Plugin is scriptable from JavaScript.
* Mon Aug 25 2008 lmichnovic@suse.cz
- update to version 4.4
  * Full session management under X11.
  * Added advanced feature check box.
  * Added advanced command to copy urls, outline, etc.
  * New translation (russian)
  * History in the find dialog.
  * Option to display hidden text in status bar.
  * Option to display the first page alone in side-by-side mode.
  * Option to display side-by-side in right-to-left mode.
  * Drag'n drop files into the viewer.
  * Support for Lizardtech's plugin option -showposition.
* Fri Feb  1 2008 lmichnovic@suse.cz
- update to version 4.3
  * Undo/Redo
  * New translations (german,czech)
  * Fixed double free bug in plugin mode.
* Mon Dec 10 2007 lmichnovic@suse.cz
- update to version 4.2
  obsoletes semicolon.patch
  * Better support of Qt/Mac
  * Recent files menu
  * Open Location
  * Undo/Redo
  * Escape can be used to exit full screen mode
  * New translation (german)
* Fri Jul 13 2007 lmichnovic@suse.cz
- made conflict with splitted off djvulibre-djview3 package
- added missing ending semicolon in desktop file (semicolon.patch)
- changed SuSE default browser plugin path in man page
  (nsplugin_manpage.patch) and for installation (nsplugin_dir.patch)
* Thu Jul 12 2007 lmichnovic@suse.cz
- initial package djvulibre-djview4 version 4.1
